@@ -3,11 +3,62 @@ import time
 import socket
 import paramiko
 import subprocess
-from log import log
 from datetime import datetime
 from func_timeout import func_set_timeout
 from func_timeout.exceptions import FunctionTimedOut
 from paramiko import SSHException
+import time
+import functools
+import logging
+import traceback
+import inspect
+from typing import Callable, Any
+from typing import List, Dict, Any, Optional
+
+log=logging.getLogger(__name__)
+
+def enter_and_leave_function(func: Callable) -> Callable:
+    """
+    函数调用日志装饰器：
+    1. 记录函数入参、调用位置
+    2. 正常执行时记录返回值
+    3. 异常时记录完整堆栈（含函数内具体报错行数）
+    """
+
+    @functools.wraps(func)  # 保留原函数元信息（如 __name__、__doc__）
+    def wrapper(*args: Any, **kwargs: Any) -> Any:
+        # 获取函数定义的文件路径和行号（基础位置信息）
+        func_def_file = inspect.getsourcefile(func) or "unknown_file"
+        func_def_file = func_def_file.split("/")[-1]
+        func_def_line = inspect.getsourcelines(func)[1] if func_def_file != "unknown_file" else "unknown_line"
+        log.info(
+            f"[{func_def_file}: {func_def_line}]"
+            f"[{func.__name__}()]"
+            f"| args={args}, kwargs={kwargs}"
+        )
+
+        try:
+            result = func(*args, **kwargs)
+            log.info(
+                f"[{func_def_file}: {func_def_line}]"
+                f" finish run function {func.__name__}(), return value is: {result} "
+            )
+            return result
+
+        except Exception as e:
+            error_traceback = traceback.format_exc()
+
+            log.error(
+                f"[{func_def_file}: {func_def_line}]"
+                f"failed to run function {func.__name__}() :Failed. "
+                f"| error_type：{type(e).__name__} "
+                f"| error_message：{str(e)} "
+                f"| full_stack_trace：\n{error_traceback}",
+                exc_info=False  # 已手动捕获堆栈，避免 logging 重复打印
+            )
+            raise  # 重新抛出异常，不中断原异常链路
+
+    return wrapper
 
 
 class ExecResult():
@@ -75,6 +126,7 @@ class SSHClient(object):
             except Exception as e:
                 pass
 
+    @enter_and_leave_function
     def wait_for_sshable(self, timeout=60):
         count=0
         while True:
@@ -85,6 +137,7 @@ class SSHClient(object):
                 return False
             time.sleep(self.__connect_timeout)
 
+    @enter_and_leave_function
     def __connect(self):
         log.info(f" {self.__ip}:{self.__port} | begin to create ssh connect.")
         try:
@@ -125,6 +178,7 @@ class SSHClient(object):
         except:
             pass
 
+    @enter_and_leave_function
     def _exec(self, cmd, promt_response,timeout=60):
         log.info(f" {self.__ip}:{self.__port} | begin to run cmd:{cmd}.")
         try:
@@ -176,6 +230,7 @@ class SSHClient(object):
             return ExecResult(1, "", str(e))
 
     @func_set_timeout(1800)
+    @enter_and_leave_function
     def exec(self, cmd, promt_response=[], timeout=60):
         try:
             if not self.__ssh:
@@ -186,6 +241,7 @@ class SSHClient(object):
             log.warning(f"when run cmd: {cmd}, meets exception, err msg is {str(e)}")
             return ExecResult(1, "", str(e))
 
+    @enter_and_leave_function
     def _scp_to_remote(self, local_path, remote_path):
         log.info(
             f" {self.__ip}:{self.__port} | Begin to copy file from local {local_path} to remote host {remote_path}.")
@@ -200,6 +256,7 @@ class SSHClient(object):
                 f" {self.__ip}:{self.__port} | failed to copy file from local {local_path} to remote host{remote_path}:Error.")
             return False
 
+    @enter_and_leave_function
     def scp_to_remote(self, local_path, remote_path,timeout=120):
         try:
             if not self.__ssh:
@@ -212,6 +269,7 @@ class SSHClient(object):
             log.warning(f"when scp from local {local_path} to remote {remote_path}, meets exception.", exc_info=True)
             return False
 
+    @enter_and_leave_function
     def _scp_file_to_local(self, remote_path, local_path):
         log.info(
             f" {self.__ip}:{self.__port} | Begin to copy file from remote {remote_path} to local host {local_path}.")
@@ -222,6 +280,7 @@ class SSHClient(object):
             f" {self.__ip}:{self.__port} | Success to copy file from remote {remote_path} to local host{local_path}:OK.")
         return True
 
+    @enter_and_leave_function
     def scp_file_to_local(self, remote_path, local_path,timeout=120):
         try:
             if not self.__ssh:
